@@ -26,6 +26,19 @@ class TestColumn(NumericStatsMixin):
         pass
 
 
+class TestColumnWProps(TestColumn):
+    # overrides the property func
+    median = None
+    mode = None
+    median_abs_deviation = None
+
+    def __init__(self):
+        super().__init__()
+        self.median = None
+        self.mode = None
+        self.median_abs_deviation = None
+
+
 class TestNumericStatsMixin(unittest.TestCase):
 
     @mock.patch.multiple(NumericStatsMixin, __abstractmethods__=set(),
@@ -463,6 +476,64 @@ class TestNumericStatsMixin(unittest.TestCase):
                                         subset_properties)
         self.assertEqual(subset_properties["num_negatives"], 4)
 
+    def test_fold_histogram(self):
+        num_profiler = TestColumn()
+
+        # the break point is at the mid point of a bin
+        bin_counts = np.array([1/6, 1/6, 1/6, 1/6, 1/6, 1/6])
+        bin_edges = np.array([0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7])
+        value = 0.35
+
+        histogram_pos, histogram_neg = num_profiler._fold_histogram(
+            bin_counts, bin_edges, value)
+        bin_counts_pos, bin_edges_pos = histogram_pos[0], histogram_pos[1]
+        bin_counts_neg, bin_edges_neg = histogram_neg[0], histogram_neg[1]
+        self.assertCountEqual(np.round([1/12, 1/6, 1/6, 1/6], 10),
+                              np.round(bin_counts_pos, 10))
+        self.assertCountEqual(np.round([0, 0.05, 0.15, 0.25, 0.35], 10),
+                              np.round(bin_edges_pos, 10))
+        self.assertCountEqual(np.round([1/12, 1/6, 1/6], 10),
+                              np.round(bin_counts_neg, 10))
+        self.assertCountEqual(np.round([0, 0.05, 0.15, 0.25], 10),
+                              np.round(bin_edges_neg, 10))
+
+        # the break point is at the middle of a bin, and divides the bin
+        # into two parts with the ratio 1/4, 3/4
+        bin_counts = np.array([1 / 6, 1 / 6, 1 / 6, 1 / 6, 1 / 6, 1 / 6])
+        bin_edges = np.array([0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7])
+        value = 0.325
+
+        histogram_pos, histogram_neg = num_profiler._fold_histogram(
+            bin_counts, bin_edges, value)
+        bin_counts_pos, bin_edges_pos = histogram_pos[0], histogram_pos[1]
+        bin_counts_neg, bin_edges_neg = histogram_neg[0], histogram_neg[1]
+        self.assertCountEqual(np.round([3 / 24, 1 / 6, 1 / 6, 1 / 6], 10),
+                              np.round(bin_counts_pos, 10))
+        self.assertCountEqual(np.round([0, 0.075, 0.175, 0.275, 0.375], 10),
+                              np.round(bin_edges_pos, 10))
+        self.assertCountEqual(np.round([1 / 24, 1 / 6, 1 / 6], 10),
+                              np.round(bin_counts_neg, 10))
+        self.assertCountEqual(np.round([0, 0.025, 0.125, 0.225], 10),
+                              np.round(bin_edges_neg, 10))
+
+        # the break point is at the edge of a bin
+        bin_counts = np.array([1 / 6, 1 / 6, 1 / 6, 1 / 6, 1 / 6, 1 / 6])
+        bin_edges = np.array([0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7])
+        value = 0.3
+
+        histogram_pos, histogram_neg = num_profiler._fold_histogram(
+            bin_counts, bin_edges, value)
+        bin_counts_pos, bin_edges_pos = histogram_pos[0], histogram_pos[1]
+        bin_counts_neg, bin_edges_neg = histogram_neg[0], histogram_neg[1]
+        self.assertCountEqual(np.round([1 / 6, 1 / 6, 1 / 6, 1 / 6], 10),
+                              np.round(bin_counts_pos, 10))
+        self.assertCountEqual(np.round([0, 0.1, 0.2, 0.3, 0.4], 10),
+                              np.round(bin_edges_pos, 10))
+        self.assertCountEqual(np.round([1 / 6, 1 / 6], 10),
+                              np.round(bin_counts_neg, 10))
+        self.assertCountEqual(np.round([0, 0.1, 0.2], 10),
+                              np.round(bin_edges_neg, 10))
+
     def test_timeit_num_zeros_and_negatives(self):
         """
         Checks num_zeros and num_negatives have been timed
@@ -522,12 +593,14 @@ class TestNumericStatsMixin(unittest.TestCase):
         mock_profile = dict(
             min=1.0,
             max=1.0,
-            mode=np.nan, # default
+            median=np.nan, # default
+            mode=[np.nan], # default
             sum=1.0,
             mean=0, # default
             variance=np.nan, # default
             skewness=np.nan, # default
             kurtosis=np.nan, # default
+            median_abs_deviation=np.nan, # default
             stddev=np.nan, # default
             histogram={
                 'bin_counts': np.array([1, 1, 1]),
@@ -580,18 +653,24 @@ class TestNumericStatsMixin(unittest.TestCase):
         Checks _diff_helper() works appropriately.
         """
 
-        other1, other2 = TestColumn(), TestColumn()
+        other1, other2 = TestColumnWProps(), TestColumnWProps()
         other1.min = 3
         other1.max = 4
         other1._biased_variance = 1
         other1.sum = 6
         other1.match_count = 10
+        other1.median = 5
+        other1.mode = [3]
+        other1.median_abs_deviation = 4
         
         other2.min = 3
         other2.max = None
         other2._biased_variance = 9
         other2.sum = 6
         other2.match_count = 20
+        other2.median = 6
+        other2.mode = [2]
+        other2.median_abs_deviation = 3
 
         # T-stat and Welch's df calculation can be found here:
         #    https://en.wikipedia.org/wiki/Welch%27s_t-test#Calculations
@@ -602,6 +681,9 @@ class TestNumericStatsMixin(unittest.TestCase):
             'max': [4, None],
             'sum': 'unchanged',
             'mean': 0.3,
+            'median': -1,
+            'mode': [[3], [], [2]],
+            'median_absolute_deviation': 1,
             'variance': 10 / 9 - (9 * 20 / 19),
             'stddev': np.sqrt(10 / 9) - np.sqrt(9 * 20 / 19),
             't-test': {
@@ -616,28 +698,39 @@ class TestNumericStatsMixin(unittest.TestCase):
                 }
             }
         }
+
         difference = other1.diff(other2)
+        self.maxDiff = None
         self.assertDictEqual(expected_diff, difference)
 
         # Invalid statistics
-        other1, other2 = TestColumn(), TestColumn()
+        other1, other2 = TestColumnWProps(), TestColumnWProps()
         other1.min = 3
         other1.max = 4
         other1._biased_variance = np.nan # NaN variance
         other1.sum = 6
         other1.match_count = 10
+        other1.median = 5
+        other1.mode = [3]
+        other1.median_abs_deviation = 4
 
         other2.min = 3
         other2.max = None
         other2._biased_variance = 9
         other2.sum = 6
         other2.match_count = 20
+        other2.median = 6
+        other2.mode = [2]
+        other2.median_abs_deviation = 3
 
         expected_diff = {
             'min': 'unchanged',
             'max': [4, None],
             'sum': 'unchanged',
             'mean': 0.3,
+            'median': -1,
+            'mode': [[3], [], [2]],
+            'median_absolute_deviation': 1,
             'variance': np.nan,
             'stddev': np.nan,
             't-test': {
@@ -664,24 +757,33 @@ class TestNumericStatsMixin(unittest.TestCase):
         self.assertTrue(np.isnan([expected_var, var, expected_stddev, stddev]).all())
 
         # Insufficient match count
-        other1, other2 = TestColumn(), TestColumn()
+        other1, other2 = TestColumnWProps(), TestColumnWProps()
         other1.min = 3
         other1.max = 4
         other1._biased_variance = 1
         other1.sum = 6
         other1.match_count = 10
+        other1.median = 5
+        other1.mode = [3]
+        other1.median_abs_deviation = 4
 
         other2.min = 3
         other2.max = None
         other2._biased_variance = 9
         other2.sum = 6
         other2.match_count = 1 # Insufficient count
+        other2.median = 6
+        other2.mode = [2]
+        other2.median_abs_deviation = 3
 
         expected_diff = {
             'min': 'unchanged',
             'max': [4, None],
             'sum': 'unchanged',
             'mean': -5.4,
+            'median': -1,
+            'mode': [[3], [], [2]],
+            'median_absolute_deviation': 1,
             'variance': np.nan,
             'stddev': np.nan,
             't-test': {
@@ -708,24 +810,33 @@ class TestNumericStatsMixin(unittest.TestCase):
         self.assertTrue(np.isnan([expected_var, var, expected_stddev, stddev]).all())
 
         # Small p-value
-        other1, other2 = TestColumn(), TestColumn()
+        other1, other2 = TestColumnWProps(), TestColumnWProps()
         other1.min = 3
         other1.max = 4
         other1._biased_variance = 1
         other1.sum = 6
         other1.match_count = 10
+        other1.median = 5
+        other1.mode = [3]
+        other1.median_abs_deviation = 4
 
         other2.min = 3
         other2.max = None
         other2._biased_variance = 9
         other2.sum = 60
         other2.match_count = 20
+        other2.median = 6
+        other2.mode = [2]
+        other2.median_abs_deviation = 3
 
         expected_diff = {
             'min': 'unchanged',
             'max': [4, None],
             'sum': -54,
             'mean': -2.4,
+            'median': -1,
+            'mode': [[3], [], [2]],
+            'median_absolute_deviation': 1,
             'variance': 10 / 9 - (9 * 20 / 19),
             'stddev': np.sqrt(10 / 9) - np.sqrt(9 * 20 / 19),
             't-test': {
@@ -747,5 +858,5 @@ class TestNumericStatsMixin(unittest.TestCase):
         with self.assertRaises(TypeError) as exc:
             other1.diff("Inproper input")
         self.assertEqual(str(exc.exception),
-                         "Unsupported operand type(s) for diff: 'TestColumn' and"
+                         "Unsupported operand type(s) for diff: 'TestColumnWProps' and"
                          " 'str'")
