@@ -186,6 +186,7 @@ class TestTextColumnProfiler(unittest.TestCase):
             min=1.0,
             max=4.0,
             mode=[1],
+            median=1.5,
             sum=20.0,
             mean=20.0 / 10.0,
             variance=14.0 / 9.0,
@@ -197,6 +198,7 @@ class TestTextColumnProfiler(unittest.TestCase):
                 'bin_edges': np.array([1., 1.5, 2., 2.5, 3., 3.5, 4.])
             },
             quantiles={0: 1.25, 1: 1.5, 2: 3.0},
+            median_abs_deviation=0.5,
             vocab=['a', 'b', 'c', 'd', '4', '3', '2', 'f'],
             times=defaultdict(float, {'vocab': 1.0,
                                       'max': 1.0,
@@ -215,16 +217,23 @@ class TestTextColumnProfiler(unittest.TestCase):
             profile = profiler.profile
             expected_histogram = expected_profile.pop('histogram')
             expected_quantiles = expected_profile.pop('quantiles')
+            expected_median_abs_dev = \
+                expected_profile.pop('median_abs_deviation')
             expected_vocab = expected_profile.pop('vocab')
             quantiles = profile.pop('quantiles')
             histogram = profile.pop('histogram')
+            median_abs_dev = profile.pop('median_abs_deviation')
             vocab = profile.pop('vocab')
 
-            # validate mode
+            # validate mode and median
             expected_mode = expected_profile.pop('mode')
             mode = profile.pop('mode')
             np.testing.assert_array_almost_equal(expected_mode, mode, decimal=2)
 
+            expected_median = expected_profile.pop('median')
+            median = profile.pop('median')
+            self.assertAlmostEqual(expected_median, median, places=2)
+
             # key and value populated correctly
             self.assertDictEqual(expected_profile, profile)
             self.assertTrue(np.all(
@@ -236,6 +245,8 @@ class TestTextColumnProfiler(unittest.TestCase):
             self.assertCountEqual(
                 expected_quantiles, {
                     0: quantiles[249], 1: quantiles[499], 2: quantiles[749]})
+            self.assertAlmostEqual(
+                expected_median_abs_dev, median_abs_dev, places=2)
             self.assertCountEqual(expected_vocab, vocab)
 
     def test_option_timing(self):
@@ -445,11 +456,6 @@ class TestTextColumnProfiler(unittest.TestCase):
             ["hello", "my", "name", "is", "Grant", "I", "have", "67", "dogs"]
         ).apply(str)
 
-        expected_vocab = [
-            'a', 'b', 'c', 'd', '4', '3', '2', 'f', 'h', 'e', 'l', 'o', 'm',
-            'y', 'n', 'i', 's', 'G', 'r', 't', 'I', 'v', '6', '7', 'g'
-        ]
-
         profiler1 = TextColumn(df.name)
         profiler1.update(df)
         profile1 = profiler1.profile
@@ -462,6 +468,9 @@ class TestTextColumnProfiler(unittest.TestCase):
                          'max': -1.0,
                          'sum': -9.0,
                          'mean': profile1['mean'] - profile2['mean'],
+                         'median': -2.5,
+                         'mode': [[1], [], [2, 4]],
+                         'median_absolute_deviation': -0.5,
                          'variance': profile1['variance'] - profile2['variance'],
                          'stddev': profile1['stddev'] - profiler2['stddev'],
                          'vocab': utils.find_diff_of_lists_and_sets(
@@ -478,5 +487,16 @@ class TestTextColumnProfiler(unittest.TestCase):
                              }
                          }
                          }
-        diff = profiler1.diff(profiler2)
-        self.assertDictEqual(expected_diff, diff)
+
+        profile_diff = profiler1.diff(profiler2)
+        self.assertAlmostEqual(
+            expected_diff.pop('median'), profile_diff.pop('median'), places=2)
+        expected_diff_mode = expected_diff.pop('mode')
+        diff_mode = profile_diff.pop('mode')
+        for i in range(len(expected_diff_mode)):
+            np.testing.assert_almost_equal(sorted(expected_diff_mode[i]),
+                                           sorted(diff_mode[i]), 2)
+        self.assertAlmostEqual(expected_diff.pop('median_absolute_deviation'),
+                               profile_diff.pop('median_absolute_deviation'),
+                               places=2)
+        self.assertDictEqual(expected_diff, profile_diff)
